@@ -3,7 +3,7 @@
   Copyright (C) 2003 Reinhold Kainhofer <reinhold@kainhofer.com>
   Copyright (c) 2003 Cornelius Schumacher <schumacher@kde.org>
   Copyright (c) 2008 Ron Goodheart <rong.dev@gmail.com>
-  Copyright (c) 2010-2015 Laurent Montel <montel@kde.org>
+  Copyright (c) 2010-2017 Laurent Montel <montel@kde.org>
   Copyright (c) 2012-2013 Allen Winter <winter@kde.org>
 
   This program is free software; you can redistribute it and/or modify
@@ -28,6 +28,7 @@
 #include "calprintdefaultplugins.h"
 #include "kcalprefs.h"
 #include "utils.h"
+#include "helper_p.h"
 
 #include <Item>
 
@@ -320,7 +321,7 @@ void CalPrintIncidence::print(QPainter &p, int width, int height)
             if (!recurs->exDates().isEmpty()) {
                 exceptString = i18nc("except for listed dates", " except");
                 for (int i = 0; i < recurs->exDates().size(); ++i) {
-                    exceptString.append(QStringLiteral(" "));
+                    exceptString.append(QLatin1Char(' '));
                     exceptString.append(QLocale::system().toString(recurs->exDates().at(i),
                                         QLocale::ShortFormat));
                 }
@@ -335,7 +336,7 @@ void CalPrintIncidence::print(QPainter &p, int width, int height)
             QRect alarmBox(timesBox.left() + padding(), h + padding(),
                            timesBox.right() - padding(), lineHeight);
             KCalCore::Alarm::List alarms = (*it)->alarms();
-            if (alarms.count() == 0) {
+            if (alarms.isEmpty()) {
                 cap = i18n("No reminders");
                 txt.clear();
             } else {
@@ -489,7 +490,7 @@ void CalPrintIncidence::print(QPainter &p, int width, int height)
             } else {
 
                 QString subitemCaption;
-                if (relations.count() == 0) {
+                if (relations.isEmpty()) {
                     subitemCaption = i18n("No Subitems");
                     txt.clear();
                 } else {
@@ -502,7 +503,7 @@ void CalPrintIncidence::print(QPainter &p, int width, int height)
                 QString statusString;
                 QString datesString;
                 int count = 0;
-                foreach (const Akonadi::Item &item, relations) {
+                for (const Akonadi::Item &item : qAsConst(relations)) {
                     KCalCore::Todo::Ptr todo = CalendarSupport::todo(item);
                     ++count;
                     if (!todo) {   // defensive, skip any zero pointers
@@ -573,9 +574,9 @@ void CalPrintIncidence::print(QPainter &p, int width, int height)
         }
 
         if (mShowAttachments && !isJournal) {
-            KCalCore::Attachment::List attachments = (*it)->attachments();
+            const KCalCore::Attachment::List attachments = (*it)->attachments();
             QString attachmentCaption;
-            if (attachments.count() == 0) {
+            if (attachments.isEmpty()) {
                 attachmentCaption = i18n("No Attachments");
                 txt.clear();
             } else {
@@ -597,9 +598,9 @@ void CalPrintIncidence::print(QPainter &p, int width, int height)
                                captionFont, textFont);
         }
         if (mShowAttendees) {
-            KCalCore::Attendee::List attendees = (*it)->attendees();
+            const KCalCore::Attendee::List attendees = (*it)->attendees();
             QString attendeeCaption;
-            if (attendees.count() == 0) {
+            if (attendees.isEmpty()) {
                 attendeeCaption = i18n("No Attendees");
             } else {
                 attendeeCaption = i18np("1 Attendee:",
@@ -864,7 +865,7 @@ void CalPrintDay::print(QPainter &p, int width, int height)
 
             // split out the all day events as they will be printed in a separate box
             KCalCore::Event::List alldayEvents, timedEvents;
-            foreach (const KCalCore::Event::Ptr &event, eventList) {
+            for (const KCalCore::Event::Ptr &event : qAsConst(eventList)) {
                 if (event->allDay()) {
                     alldayEvents.append(event);
                 } else {
@@ -901,7 +902,7 @@ void CalPrintDay::print(QPainter &p, int width, int height)
                 eventBox.setTop(eventBox.top() + padding());
                 eventBox.setBottom(eventBox.top() + lineSpacing);
                 int count = 0;
-                foreach (const KCalCore::Event::Ptr &event, alldayEvents) {
+                for (const KCalCore::Event::Ptr &event : qAsConst(alldayEvents)) {
                     if (count == maxAllDayEvents) {
                         break;
                     }
@@ -1609,7 +1610,7 @@ void CalPrintTodos::print(QPainter &p, int width, int height)
     case TodosAll:
         break;
     case TodosUnfinished:
-        foreach (const KCalCore::Todo::Ptr &todo, todoList) {
+        for (const KCalCore::Todo::Ptr &todo : qAsConst(todoList)) {
             Q_ASSERT(todo);
             if (!todo->isCompleted()) {
                 tempList.append(todo);
@@ -1618,7 +1619,7 @@ void CalPrintTodos::print(QPainter &p, int width, int height)
         todoList = tempList;
         break;
     case TodosDueRange:
-        foreach (const KCalCore::Todo::Ptr &todo, todoList) {
+        for (const KCalCore::Todo::Ptr &todo : qAsConst(todoList)) {
             Q_ASSERT(todo);
             if (todo->hasDueDate()) {
                 if (todo->dtDue().date() >= mFromDate && todo->dtDue().date() <= mToDate) {
@@ -1634,7 +1635,7 @@ void CalPrintTodos::print(QPainter &p, int width, int height)
 
     // Print to-dos
     int count = 0;
-    foreach (const KCalCore::Todo::Ptr &todo, todoList) {
+    for (const KCalCore::Todo::Ptr &todo : qAsConst(todoList)) {
         if ((mExcludeConfidential && todo->secrecy() == KCalCore::Incidence::SecrecyConfidential) ||
                 (mExcludePrivate      && todo->secrecy() == KCalCore::Incidence::SecrecyPrivate)) {
             continue;
@@ -1647,7 +1648,7 @@ void CalPrintTodos::print(QPainter &p, int width, int height)
                      mConnectSubTodos,
                      mStrikeOutCompleted, mIncludeDescription,
                      pospriority, possummary, posdue, poscomplete,
-                     0, 0, mCurrentLinePos, width, height, todoList, 0,
+                     0, 0, mCurrentLinePos, width, height, todoList, nullptr,
                      mExcludeConfidential, mExcludePrivate);
         }
     }
